2024-03-15 Version: 2.0.5
- Update API CreateTask: update param body.


2024-03-12 Version: 2.0.4
- Update API CreateTask: update response param.
- Update API GetTaskInfo: update response param.


2024-02-23 Version: 2.0.3
- Update API GetTaskInfo: update response param.


2024-01-08 Version: 2.0.2
- Generated python2 2023-09-30 for tingwu.

2023-12-25 Version: 2.0.1
- Generated python2 2023-09-30 for tingwu.

2023-12-20 Version: 2.0.0
- Generated python2 2023-09-30 for tingwu.

2023-12-19 Version: 1.1.2
- Generated python2 2023-09-30 for tingwu.

2023-12-18 Version: 1.1.1
- Generated python2 2023-09-30 for tingwu.

2023-12-12 Version: 1.1.0
- Generated python2 2023-09-30 for tingwu.

2023-12-01 Version: 1.0.1
- Generated python2 2023-09-30 for tingwu.

2023-11-03 Version: 1.0.0
- Generated python2 2023-09-30 for tingwu.

